==> polls-v1.4.1.zip: polls/messages/sv/base.php <==
<?php

return [
    '<strong>Note:</strong> The result is hidden until the poll is closed by a moderator.' => '<strong>OBS:</strong> Resultatet är dolt tills undersökningen är stängd av moderatorn.',
    'Access denied!' => 'Tillträde nekas!',
    'Add answer...' => 'Lägg till svar...',
    'Again? ;Weary;' => 'Om igen? ;Trötta;',
    'Allows the user to create polls' => 'Låter användaren skapa undersökningar',
    'Allows to start polls.' => 'Tillåtelse att starta undersökningar.',
    'Anonymous' => 'Anonym',
    'Anonymous Votes?' => 'Anonyma röster?',
    'Anonymous poll!' => 'Anonym enkät!',
    'Answers' => 'Svar',
    'At least one answer is required' => 'Minst ett svar krävs',
    'Cancel' => 'Avbryt',
    'Close Poll' => 'Avsluta undersökning',
    'Closed' => 'Stängd',
    'Club A Steakhouse' => 'Club A Steakhouse',
    'Could not load poll!' => 'Kunde inte ladda enkät!',
    'Create poll' => 'Skapa undersökning',
    'Description' => 'Beskrivning',
    'Display answers in random order?' => 'Visa svar i slumpmässig ordning?',
    'Edit answer (empty answers will be removed)...' => 'Redigera svar (tomma svar kommer att tas bort)...',
    'Edit your poll question...' => 'Redigera din enkät fråga',
    'Hide results until poll is closed?' => 'Dölj resultat tills enkäten är avslutad?',
    'Invalid answer!' => 'Felaktigt svar!',
    'Location of the next meeting' => 'Plats för nästa möte',
    'Multiple answers per user' => 'Flera svar per användare',
    'Pisillo Italian Panini' => 'Pisillo italienska Panini',
    'Please specify at least {min} answers!' => 'Ange minst {min} svar!',
    'Poll' => 'Enkät',
    'Polls' => 'Enkät',
    'Question' => 'Fråga',
    'Reopen Poll' => 'Återöppna undersökning',
    'Reset my vote' => 'Återställ min röstning',
    'Right now, we are in the planning stages for our next meetup and we would like to know from you, where you would like to go?' => 'Just nu är vi i planeringsstadiet för vår nästa träff och vi skulle vilja veta vart du skulle vilja åka?',
    'Save' => 'Spara',
    'To Daniel' => 'Till Daniel',
    'Users voted for: <strong>{answer}</strong>' => 'Användarna röstade för: <strong>{answer}</strong>',
    'Vote' => 'Rösta',
    'Voting for multiple answers is disabled!' => 'Att rösta på flera alternativ är avstängt!',
    'Whenever someone participates in a poll.' => 'När någon deltar i en enkät.',
    'Why don\'t we go to Bemelmans Bar?' => 'Varför går vi inte till Bemelmans Bar?',
    'You have insufficient permissions to perform that operation!' => 'Du har inte tillräckliga rättigheter för att göra detta!',
    'and {count} more vote for this.' => 'och {count} fler röster för detta.',
    'votes' => 'röster',
    '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}' => '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}',
    '{userName} answered the {question}.' => '{userName} svarade på {question}.',
    'Poll content ID' => '',
];

==> polls-v1.4.2.zip: polls/messages/sv/base.php <==
<?php

return [
    '<strong>Note:</strong> The result is hidden until the poll is closed by a moderator.' => '<strong>OBS:</strong> Resultatet är dolt tills undersökningen är stängd av moderatorn.',
    'Access denied!' => 'Tillträde nekas!',
    'Add answer...' => 'Lägg till svar...',
    'Again? :weary:' => 'Om igen? ;Trötta;',
    'Allows the user to create polls' => 'Låter användaren skapa undersökningar',
    'Allows to start polls.' => 'Tillåtelse att starta undersökningar.',
    'Anonymous' => 'Anonym',
    'Anonymous Votes?' => 'Anonyma röster?',
    'Anonymous poll!' => 'Anonym enkät!',
    'Answers' => 'Svar',
    'At least one answer is required' => 'Minst ett svar krävs',
    'Cancel' => 'Avbryt',
    'Close Poll' => 'Avsluta undersökning',
    'Closed' => 'Stängd',
    'Club A Steakhouse' => 'Club A Steakhouse',
    'Could not load poll!' => 'Kunde inte ladda enkät!',
    'Create poll' => 'Skapa undersökning',
    'Description' => 'Beskrivning',
    'Display answers in random order?' => 'Visa svar i slumpmässig ordning?',
    'Edit answer (empty answers will be removed)...' => 'Redigera svar (tomma svar kommer att tas bort)...',
    'Edit your poll question...' => 'Redigera din enkät fråga',
    'Hide results until poll is closed?' => 'Dölj resultat tills enkäten är avslutad?',
    'Invalid answer!' => 'Felaktigt svar!',
    'Location of the next meeting' => 'Plats för nästa möte',
    'Multiple answers per user' => 'Flera svar per användare',
    'Pisillo Italian Panini' => 'Pisillo italienska Panini',
    'Please specify at least {min} answers!' => 'Ange minst {min} svar!',
    'Poll' => 'Enkät',
    'Polls' => 'Enkät',
    'Question' => 'Fråga',
    'Reopen Poll' => 'Återöppna undersökning',
    'Reset my vote' => 'Återställ min röstning',
    'Right now, we are in the planning stages for our next meetup and we would like to know from you, where you would like to go?' => 'Just nu är vi i planeringsstadiet för vår nästa träff och vi skulle vilja veta vart du skulle vilja åka?',
    'Save' => 'Spara',
    'To Daniel' => 'Till Daniel',
    'Users voted for: <strong>{answer}</strong>' => 'Användarna röstade för: <strong>{answer}</strong>',
    'Vote' => 'Rösta',
    'Voting for multiple answers is disabled!' => 'Att rösta på flera alternativ är avstängt!',
    'Whenever someone participates in a poll.' => 'När någon deltar i en enkät.',
    'Why don\'t we go to Bemelmans Bar?' => 'Varför går vi inte till Bemelmans Bar?',
    'You have insufficient permissions to perform that operation!' => 'Du har inte tillräckliga rättigheter för att göra detta!',
    'and {count} more vote for this.' => 'och {count} fler röster för detta.',
    'votes' => 'röster',
    '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}' => '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}',
    '{userName} answered the {question}.' => '{userName} svarade på {question}.',
    'Poll content ID' => '',
];
